@@ -379,6 +379,91 @@ def list_current_pods(label_selector: str = None):
     return res["items"]
 
 
+def list_storage_pvc():
+    load_kube_config()
+    api_instance = CoreV1Api()
+    props = get_properties()
+    team_name = props["AWS_ORBIT_TEAM_SPACE"]
+    _logger.debug(f"Listing {team_name} namespace persistent volume claims")
+    params = dict()
+    params["namespace"] = team_name
+    params["_preload_content"] = False
+    try:
+        api_response = api_instance.list_namespaced_persistent_volume_claim(**params)
+        res = json.loads(api_response.data)
+    except ApiException as e:
+        _logger.info("Exception when calling CoreV1Api->list persistent volume claims: %s\n" % e)
+        raise e
+
+    if "items" not in res:
+        return []
+
+    return res["items"]
+
+
+def delete_storage_pvc(pvc_name: str):
+    load_kube_config()
+    api_instance = CoreV1Api()
+    props = get_properties()
+    team_name = props["AWS_ORBIT_TEAM_SPACE"]
+    _logger.debug(f"Deleting {team_name} namespace persistent volume claim {pvc_name}")
+    params = dict()
+    params["name"] = pvc_name
+    params["namespace"] = team_name
+    params["_preload_content"] = False
+    try:
+        api_response = api_instance.delete_namespaced_persistent_volume_claim(**params)
+        response = {
+            "status": str(api_response.status),
+            "reason": api_response.reason,
+            "message": f"Successfully deleted persistent volume claim={pvc_name}",
+        }
+    except ApiException as e:
+        _logger.info("Exception when calling CoreV1Api->delete persistent volume claim: %s\n" % e)
+        e_body = json.loads(e.body)
+        response = {"status": str(e_body["code"]), "reason": e_body["reason"], "message": e_body["message"]}
+
+    return response
+
+
+def list_storage_pv():
+    load_kube_config()
+    api_instance = CoreV1Api()
+    _logger.debug("Listing cluster persistent volumes")
+    params = dict()
+    params["_preload_content"] = False
+    try:
+        api_response = api_instance.list_persistent_volume(**params)
+        res = json.loads(api_response.data)
+    except ApiException as e:
+        _logger.info("Exception when calling CoreV1Api->list persistent volumes : %s\n" % e)
+        raise e
+
+    if "items" not in res:
+        return []
+
+    return res["items"]
+
+
+def list_storage_class():
+    load_kube_config()
+    api_instance = StorageV1Api()
+    _logger.debug("Listing cluster storage classes")
+    params = dict()
+    params["_preload_content"] = False
+    try:
+        api_response = api_instance.list_storage_class(**params)
+        res = json.loads(api_response.data)
+    except ApiException as e:
+        _logger.info("Exception when calling StorageV1Api->list storage class : %s\n" % e)
+        raise e
+
+    if "items" not in res:
+        return []
+
+    return res["items"]
+
+
 def delete_job(job_name: str, grace_period_seconds: int = 30):
     props = get_properties()
     global __CURRENT_TEAM_MANIFEST__, __CURRENT_ENV_MANIFEST__
