@@ -9,6 +9,8 @@ from urllib.parse import quote_plus
 
 import boto3
 import IPython.core.display
+import pandas as pd
+import pyathena
 import sqlalchemy as sa
 from IPython import get_ipython
 from IPython.display import JSON
@@ -999,3 +1001,18 @@ class AthenaUtils(DatabaseCommon):
                 col["type"] = c["Type"]
 
         return display_json(schemas, root="glue databases")
+
+    def get_sample_data(self, database: str, table: str, sample: int, field: str, direction: str):
+        workspace = get_workspace()
+        logger.info(f"query staging location: s3://{workspace['ScratchBucket']}/athena/query/")
+        conn = pyathena.connect(
+            s3_staging_dir=f"s3://{workspace['ScratchBucket']}/{workspace['team_space']}/athena/query/",
+            region_name=workspace["region"],
+        )
+        if field and len(field) > 0:
+            query = f'SELECT * FROM "{database}"."{table}" order by {field} desc LIMIT {sample}'
+        else:
+            query = f'SELECT * FROM "{database}"."{table}" LIMIT {sample}'
+        df = pd.read_sql(query, conn)
+        result = df.to_json(orient="records")
+        return result
